# pkg-dependency-manager

This is a package dependency manager, written in Python 3.9. Its main purpose is to easily manage packages via Homebrew, apt-get, pacman, etc.

`pkg-dependency-manager` currently supports the following platforms:
- Arch Linux
- Ubuntu
- MacOS X